@@ -92,7 +92,12 @@ class Database:
                         first_date = min_date_of_ohlc_df
 
                     last_date = str(max([int(qfq_df.loc[qfq_df.index[-1], 'date']), int(df.loc[df.index[-1], 'date'])]))
-                    qfq_df['date'] = pd.to_datetime(qfq_df['date'], format='%Y-%m-%d')
+
+                    if '-' in qfq_df.at[0, 'date']:
+                        qfq_df['date'] = pd.to_datetime(qfq_df['date'], format='%Y-%m-%d')
+                    else:
+                        qfq_df['date'] = pd.to_datetime(qfq_df['date'], format='%Y%m%d')
+                        
                     qfq_df = qfq_df.set_index(keys='date')
                     t_index = pd.DatetimeIndex(pd.date_range(start=first_date, end=last_date, freq='1D'))
 
